# py-droplets

[![Build Status](https://github.com/zwicker-group/py-droplets/actions/workflows/python_tests.yml/badge.svg)](https://github.com/zwicker-group/py-droplets/actions/workflows/python_tests.yml)
[![Documentation Status](https://readthedocs.org/projects/py-droplets/badge/?version=latest)](https://py-droplets.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/py-droplets.svg)](https://badge.fury.io/py/py-droplets)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/py-droplets.svg)](https://anaconda.org/conda-forge/py-droplets)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![codecov](https://codecov.io/gh/zwicker-group/py-droplets/branch/master/graph/badge.svg)](https://codecov.io/gh/zwicker-group/py-droplets)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

`py-droplets` provides python code for representing physical droplets using
key parameters like position, size, or shape.
These droplets can also be represented as collections (emulsions) and over time.
Moreover, the package provides methods for locating droplets in microscope
images or phase field data from simulations.


Installation
------------

`py-droplets` is available on `pypi`, so you should be able to install it
through `pip`:

```bash
pip install py-droplets
```

As an alternative, you can install `py-droplets` through [conda](https://docs.conda.io/en/latest/)
using the [conda-forge](https://conda-forge.org/) channel:

```bash
conda install -c conda-forge py-droplets
```


Usage
-----

More information
----------------
* Tutorial notebook in the [tutorials folder](https://github.com/zwicker-group/py-droplets/tree/master/examples/tutorial)
* Examples in the [examples folder](https://github.com/zwicker-group/py-droplets/tree/master/examples)
* [Full documentation on readthedocs](https://py-droplets.readthedocs.io/)
  or as [a single PDF file](https://py-droplets.readthedocs.io/_/downloads/en/latest/pdf/).
